@@ -2160,7 +2160,6 @@ def FocusSweep(oeFocussing, DefocusList, DetectorSize=50e-6, AngleInNominal=np.d
 		# I set the Position the detector at distance = Distance
 		# ------------------------------------------------------------
 		d.PositioningDirectives.Distance = Distance
-		print(i)
 		t.RefreshPositions()
 		t.ComputeFields(Verbose=False)
 
@@ -2170,7 +2169,7 @@ def FocusSweep(oeFocussing, DefocusList, DetectorSize=50e-6, AngleInNominal=np.d
 		More.XYCentre[i] = d.CoreOptics.XYCentre
 
 		# Debug.print(oeFocussing.CoreOptics.GetPositionString(1))
-		print(d.CoreOptics.XYCentre)
+		# print(d.CoreOptics.XYCentre)
 		# Debug.print(d.CoreOptics.GetPositionString(1))
 
 		# Preparing and storing the results
